@@ -4,20 +4,20 @@
  * Copyright (C) 2001 Havoc Pennington
  * Copyright (C) 2002 Mathias Hasselmann
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is part of gnome-terminal.
  *
- * This library is distributed in the hope that it will be useful,
+ * Gnome-terminal is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Gnome-terminal is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "terminal-intl.h"
@@ -70,6 +70,7 @@
 #define KEY_USE_SYSTEM_FONT "use_system_font"
 #define KEY_USE_SKEY "use_skey"
 #define KEY_FONT "font"
+#define KEY_NO_AA_WITHOUT_RENDER "no_aa_without_render" 
 
 struct _TerminalProfilePrivate
 {
@@ -128,6 +129,7 @@ struct _TerminalProfilePrivate
   guint scroll_background : 1;
   guint use_theme_colors : 1;
   guint use_system_font : 1;
+  guint no_aa_without_render : 1;
   guint use_skey : 1;
   guint forgotten : 1;
 };
@@ -291,6 +293,7 @@ terminal_profile_init (TerminalProfile *profile)
   profile->priv->delete_binding = TERMINAL_ERASE_ESCAPE_SEQUENCE;
   profile->priv->use_theme_colors = TRUE;
   profile->priv->use_system_font = TRUE;
+  profile->priv->no_aa_without_render = TRUE;
   profile->priv->use_skey = TRUE;
   profile->priv->font = pango_font_description_new ();
   pango_font_description_set_family (profile->priv->font,
@@ -1421,6 +1424,14 @@ terminal_profile_set_use_theme_colors (TerminalProfile *profile,
   g_free (key);
 }
 
+gboolean
+terminal_profile_get_no_aa_without_render (TerminalProfile *profile)
+{
+  g_return_val_if_fail (TERMINAL_IS_PROFILE (profile), FALSE);
+
+  return profile->priv->no_aa_without_render;
+}
+
 gboolean
 terminal_profile_get_use_system_font (TerminalProfile *profile)
 {
@@ -1730,17 +1741,30 @@ set_palette (TerminalProfile *profile,
 {  
   if (candidate_str != NULL)
     {
+      int i;
       GdkColor new_palette[TERMINAL_PALETTE_SIZE];
 
       if (!terminal_palette_from_string (candidate_str,
                                          new_palette,
                                          TRUE))
-        return FALSE;
-
-      if (memcmp (profile->priv->palette, new_palette,
-                  TERMINAL_PALETTE_SIZE * sizeof (GdkColor)) == 0)
-        return FALSE;
+        {
+          return FALSE;
+        }
 
+      for (i = 0; i < TERMINAL_PALETTE_SIZE; i++)
+        {
+          if (!gdk_color_equal (&profile->priv->palette[i],
+                                &new_palette[i]))
+            {
+              break;
+            }
+        }
+      
+      if (i == TERMINAL_PALETTE_SIZE)
+        {
+          return FALSE;
+        }
+              
       memcpy (profile->priv->palette, new_palette,
               TERMINAL_PALETTE_SIZE * sizeof (GdkColor));
 
@@ -1991,6 +2015,7 @@ terminal_profile_update (TerminalProfile *profile)
   UPDATE_STRING  (KEY_DELETE_BINDING,       delete_binding);
   UPDATE_BOOLEAN (KEY_USE_THEME_COLORS,     use_theme_colors);
   UPDATE_BOOLEAN (KEY_USE_SYSTEM_FONT,      use_system_font);
+  UPDATE_BOOLEAN (KEY_NO_AA_WITHOUT_RENDER, no_aa_without_render);
   UPDATE_STRING  (KEY_FONT,                 font);
   
 #undef UPDATE_BOOLEAN
@@ -2137,6 +2162,7 @@ else if (strcmp (key, KName) == 0)                                      \
      UPDATE_STRING  (KEY_DELETE_BINDING,         delete_binding,         NULL);
      UPDATE_BOOLEAN (KEY_USE_THEME_COLORS,       use_theme_colors,       TRUE);
      UPDATE_BOOLEAN (KEY_USE_SYSTEM_FONT,        use_system_font,        TRUE);
+     UPDATE_BOOLEAN (KEY_NO_AA_WITHOUT_RENDER,	 no_aa_without_render,	 TRUE);
      UPDATE_STRING  (KEY_FONT,                   font,                   NULL);
    }
   
@@ -2870,6 +2896,14 @@ terminal_profile_create (TerminalProfile *base_profile,
                          &err);
   BAIL_OUT_CHECK ();
 
+  g_free (key);
+  key = gconf_concat_dir_and_key (profile_dir,
+                                  KEY_NO_AA_WITHOUT_RENDER);
+  gconf_client_set_bool (base_profile->priv->conf,
+                         key, base_profile->priv->no_aa_without_render,
+                         &err);
+  BAIL_OUT_CHECK ();
+
   g_free (key);
   key = gconf_concat_dir_and_key (profile_dir,
                                   KEY_FONT);
@@ -3186,6 +3220,27 @@ terminal_setting_mask_equal (const TerminalSettingMask *a,
   return memcmp (a, b, sizeof (*a)) == 0;
 }
 
+const GdkColor
+terminal_palette_tango[TERMINAL_PALETTE_SIZE] =
+{
+  { 0, 0x2e2e, 0x3434, 0x3636 },
+  { 0, 0xcccc, 0x0000, 0x0000 },
+  { 0, 0x4e4e, 0x9a9a, 0x0606 },
+  { 0, 0xc4c4, 0xa0a0, 0x0000 },
+  { 0, 0x3434, 0x6565, 0xa4a4 },
+  { 0, 0x7575, 0x5050, 0x7b7b },
+  { 0, 0x0606, 0x9820, 0x9a9a },
+  { 0, 0xd3d3, 0xd7d7, 0xcfcf },
+  { 0, 0x5555, 0x5757, 0x5353 },
+  { 0, 0xefef, 0x2929, 0x2929 },
+  { 0, 0x8a8a, 0xe2e2, 0x3434 },
+  { 0, 0xfcfc, 0xe9e9, 0x4f4f },
+  { 0, 0x7272, 0x9f9f, 0xcfcf },
+  { 0, 0xadad, 0x7f7f, 0xa8a8 },
+  { 0, 0x3434, 0xe2e2, 0xe2e2 },
+  { 0, 0xeeee, 0xeeee, 0xecec }
+};
+
 const GdkColor
 terminal_palette_linux[TERMINAL_PALETTE_SIZE] =
 {
