@@ -256,13 +256,9 @@ void terminal_profile_set_delete_binding        (TerminalProfile        *profile
 void terminal_profile_set_use_theme_colors      (TerminalProfile        *profile,
                                                  gboolean                setting);
 
-
 void terminal_profile_set_use_system_font       (TerminalProfile        *profile,
 						 gboolean                setting);
 
-void terminal_profile_set_no_aa_without_render  (TerminalProfile        *profile,
-						 gboolean                setting);
-
 void terminal_profile_set_use_skey              (TerminalProfile        *profile,
 						 gboolean                setting);
 void terminal_profile_set_font                   (TerminalProfile            *profile,
@@ -303,6 +299,7 @@ gboolean terminal_setting_mask_equal    (const TerminalSettingMask *a,
 extern const GdkColor terminal_palette_linux[TERMINAL_PALETTE_SIZE];
 extern const GdkColor terminal_palette_xterm[TERMINAL_PALETTE_SIZE];
 extern const GdkColor terminal_palette_rxvt[TERMINAL_PALETTE_SIZE];
+extern const GdkColor terminal_palette_tango[TERMINAL_PALETTE_SIZE];
 
 char*    terminal_palette_to_string   (const GdkColor *palette);
 gboolean terminal_palette_from_string (const char     *str,
